Developing with nose
====================

Get the code
------------

nose is hosted at `GitHub
<http://github.com/nose-devs/nose/>`__. You should clone this
repository if you're developing a plugin or working on bug fixes for nose::

  git clone https://github.com/nose-devs/nose

You should **fork** this repository if you are developing new features for
nose. Then submit your changes as a pull request.


Read
----

.. toctree ::
   :maxdepth: 2

   plugins
   api
   contributing
